@@ -19,7 +19,7 @@ from datetime import datetime
 
 from airflow.decorators import task
 from airflow.models import DAG
-from airflow.providers.microsoft.azure.hooks.azure_fileshare import AzureFileShareHook
+from airflow.providers.microsoft.azure.hooks.fileshare import AzureFileShareHook
 
 NAME = 'myfileshare'
 DIRECTORY = "mydirectory"
@@ -43,5 +43,10 @@ def delete_fileshare():
     hook.delete_share(NAME)
 
 
-with DAG("example_fileshare", schedule_interval="@once", start_date=datetime(2021, 1, 1)) as dag:
+with DAG(
+    "example_fileshare",
+    schedule_interval="@once",
+    start_date=datetime(2021, 1, 1),
+    catchup=False,
+) as dag:
     create_fileshare() >> delete_fileshare()
